This project is fork from yoyo-migrations
https://ollycope.com/software/yoyo/latest/


.env file:
SOURCE=./migrations
BATCH_MODE=off
VERBOSITY=0
EDITOR=
POST_CREATE_COMMAND=
PREFIX=

DB_DRIVER=pymssql
DB_USER=
DB_PASSWORD=
DB_HOST=
DB_PORT=
DB_NAME=
VERSION_TABLE=
